@@ -12,7 +12,7 @@
 class SHA1
 {
 public:
-  enum {HASHLEN = 20};
+  enum {HASHLEN = 20, BLOCKSIZE = 64};
   SHA1();
   ~SHA1();
   void Update(const unsigned char* data, unsigned int len);
@@ -21,6 +21,6 @@ public:
 private:
   uint32 state[5];
   uint32 count[2];
-  unsigned char buffer[64];
+  unsigned char buffer[BLOCKSIZE];
 };
 #endif /* __SHA1_H */
