@@ -63,39 +63,39 @@ BOOL CAboutDlg::OnInitDialog()
 {
   CPWDialog::OnInitDialog();
 
-  PWSversion *pPWSver = PWSversion::GetInstance();
+  const PWSversion *pPWSver = PWSversion::GetInstance();
   m_nMajor = pPWSver->GetMajor();
   m_nMinor = pPWSver->GetMinor();
   m_nBuild = pPWSver->GetBuild();
-  int nRevision = pPWSver->GetRevision();
-  bool bModified = pPWSver->IsModified();
+  CString Revision = pPWSver->GetRevision();
   CString SpecialBuild = pPWSver->GetSpecialBuild();
   
   m_appversion = pPWSver->GetAppVersion();
 
   const CString cs2go = SysInfo::IsUnderPw2go() ? L"2go " : L" ";
   if (m_nBuild == 0) { // hide build # if zero (formal release)
-    m_appversion.Format(L"%s%sV%d.%02d (%d%s)%s", AfxGetAppName(), cs2go,
-                        m_nMajor, m_nMinor, nRevision,
-                        bModified ? L"+" : L"", SpecialBuild);
+    m_appversion.Format(L"%s%sV%d.%02d%s (%s)", AfxGetAppName(), cs2go,
+                        m_nMajor, m_nMinor, SpecialBuild, Revision);
   } else {
-    m_appversion.Format(L"%s%sV%d.%02d.%02d (%d%s)%s", AfxGetAppName(), cs2go,
-                        m_nMajor, m_nMinor, m_nBuild, nRevision,
-                        bModified ? L"+" : L"", SpecialBuild);
+    m_appversion.Format(L"%s%sV%d.%02d.%02d%s (%s)", AfxGetAppName(), cs2go,
+                        m_nMajor, m_nMinor, m_nBuild, SpecialBuild, Revision);
   }
 
 #ifdef _DEBUG
-  m_appversion += L" [Debug]";
+  m_appversion += L" [D]";
 #endif
 
 #ifdef DEMO
-  m_AppVersion += L" " + CString(MAKEINTRESOURCE(IDS_DEMO));
+  m_appversion += L" " + CString(MAKEINTRESOURCE(IDS_DEMO));
 #endif
 
-  m_appcopyright = app.GetCopyrightString();
+  CString builtOnPrefix;
+  GetDlgItem(IDC_APPBUILTON)->GetWindowText(builtOnPrefix);
+  const CString builtOn =  builtOnPrefix + pPWSver->GetBuiltOn();
 
   GetDlgItem(IDC_APPVERSION)->SetWindowText(m_appversion);
-  GetDlgItem(IDC_APPCOPYRIGHT)->SetWindowText(m_appcopyright);
+  GetDlgItem(IDC_APPBUILTON)->SetWindowText(builtOn);
+  GetDlgItem(IDC_APPCOPYRIGHT)->SetWindowText(app.GetCopyrightString());
 
   m_RECExNewVerStatus.SetWindowText(m_newVerStatus);
   m_RECExNewVerStatus.RegisterOnLink(OnCheckVersion, (LPARAM)this);
@@ -126,10 +126,9 @@ void CAboutDlg::CheckNewVer()
   // and notify the user
   // First, make sure database is closed: Sensitive data with an
   // open socket makes me uneasy...
-  DboxMain *pDbx = static_cast<DboxMain *>(GetParent());
   CGeneralMsgBox gmb;
 
-  if (pDbx->GetNumEntries() != 0) {
+  if (GetMainDlg()->GetNumEntries() != 0) {
     const CString cs_txt(MAKEINTRESOURCE(IDS_CLOSE_B4_CHECK));
     const CString cs_title(MAKEINTRESOURCE(IDS_CONFIRM_CLOSE));
     INT_PTR rc = gmb.MessageBox(cs_txt, cs_title,
@@ -137,13 +136,13 @@ void CAboutDlg::CheckNewVer()
     if (rc == IDCANCEL)
       return; // no hard feelings
     // Close database, prompt for save if changed
-    pDbx->SendMessage(WM_COMMAND, ID_MENUITEM_CLOSE);
+    GetMainDlg()->SendMessage(WM_COMMAND, ID_MENUITEM_CLOSE);
     // User could have cancelled save, need to check if really closed:
-    if (pDbx->GetNumEntries() != 0)
+    if (GetMainDlg()->GetNumEntries() != 0)
       return;
   }
-  pDbx->UpdateWindow(); // show user that we closed database
-  ASSERT(pDbx->GetNumEntries() == 0);
+  GetMainDlg()->UpdateWindow(); // show user that we closed database
+  ASSERT(GetMainDlg()->GetNumEntries() == 0);
   // safe to open external connection
   m_newVerStatus.LoadString(IDS_TRYING2CONTACT_SERVER);
   UpdateData(FALSE);
