@@ -10,15 +10,16 @@
 
 #include "stdafx.h"
 #include "PasswordSafe.h"
-#include "ThisMfcApp.h"    // For Help
-#include "GeneralMsgBox.h"
+
 #include "DboxMain.h"
-#include "Fonts.h"
 
 #include "AddEdit_Basic.h"
 #include "AddEdit_PropertySheet.h"
 #include "ChangeAliasPswd.h"
 
+#include "GeneralMsgBox.h"
+#include "Fonts.h"
+
 #include "core/PWCharPool.h"
 #include "core/PWSprefs.h"
 #include "core/PWSAuxParse.h"
@@ -107,12 +108,7 @@ CAddEdit_Basic::CAddEdit_Basic(CWnd *pParent, st_AE_master_data *pAEMD)
   st_cm.flags = 0;
   vmenu_items.push_back(st_cm);
 
-  m_pex_notes = new CRichEditExtn(vmenu_items);
-}
-
-CAddEdit_Basic::~CAddEdit_Basic()
-{
-  delete m_pex_notes;
+  m_ex_notes.SetContextMenu(vmenu_items);
 }
 
 void CAddEdit_Basic::DoDataExchange(CDataExchange* pDX)
@@ -136,7 +132,7 @@ void CAddEdit_Basic::DoDataExchange(CDataExchange* pDX)
   DDX_Control(pDX, IDC_USERNAME, m_ex_username);
   DDX_Control(pDX, IDC_PASSWORD, m_ex_password);
   DDX_Control(pDX, IDC_PASSWORD2, m_ex_password2);
-  DDX_Control(pDX, IDC_NOTES, *m_pex_notes);
+  DDX_Control(pDX, IDC_NOTES, m_ex_notes);
   DDX_Control(pDX, IDC_URL, m_ex_URL);
   DDX_Control(pDX, IDC_EMAIL, m_ex_email);
   DDX_Control(pDX, IDC_VIEWDEPENDENTS, m_ViewDependentsBtn);
@@ -209,10 +205,12 @@ BOOL CAddEdit_Basic::OnInitDialog()
   Fonts::GetInstance()->ApplyPasswordFont(GetDlgItem(IDC_PASSWORD2));
 
   // Need to get change notifcations
-  m_pex_notes->SetEventMask(ENM_CHANGE | m_pex_notes->GetEventMask());
+  m_ex_notes.SetEventMask(ENM_CHANGE | m_ex_notes.GetEventMask());
 
   // Set plain text - not that it seems to do much!
-  m_pex_notes->SetTextMode(TM_PLAINTEXT);
+  m_ex_notes.SetTextMode(TM_PLAINTEXT);
+
+  m_ex_notes.SetFont(Fonts::GetInstance()->GetCurrentFont());
 
   if (M_uicaller() == IDS_EDITENTRY && M_protected() != 0) {
     GetDlgItem(IDC_STATIC_PROTECTED)->ShowWindow(SW_SHOW);
@@ -283,7 +281,7 @@ BOOL CAddEdit_Basic::OnInitDialog()
   // groups.  However, we already maintain this list in the UI to save the
   // display status, so use this instead.
   std::vector<std::wstring> vGroups;
-  M_pDbx()->GetAllGroups(vGroups);
+  GetMainDlg()->GetAllGroups(vGroups);
 
   for (std::vector<std::wstring>::iterator iter = vGroups.begin();
        iter != vGroups.end(); ++iter) {
@@ -347,20 +345,20 @@ BOOL CAddEdit_Basic::OnInitDialog()
     ShowNotes();
   } else {
     HideNotes();
-    m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, false);
-    m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, false);
+    m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, false);
+    m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, false);
   }
 
   CHARFORMAT cf = {0};
   cf.cbSize = sizeof(cf);
 
-  m_pex_notes->SetSel(0, -1);
-  m_pex_notes->SendMessage(EM_GETCHARFORMAT, SCF_SELECTION, (LPARAM)&cf);
+  m_ex_notes.SetSel(0, -1);
+  m_ex_notes.SendMessage(EM_GETCHARFORMAT, SCF_SELECTION, (LPARAM)&cf);
   m_iPointSize = cf.yHeight / 20;
 
   // Set initial Word Wrap
-  m_pex_notes->SetTargetDevice(NULL, m_bWordWrap ? 0 : 1);
-  m_pex_notes->UpdateState(PWS_MSG_EDIT_WORDWRAP, m_bWordWrap);
+  m_ex_notes.SetTargetDevice(NULL, m_bWordWrap ? 0 : 1);
+  m_ex_notes.UpdateState(PWS_MSG_EDIT_WORDWRAP, m_bWordWrap);
 
   UpdateData(FALSE);
   m_bInitdone = true;
@@ -496,7 +494,7 @@ BOOL CAddEdit_Basic::PreTranslateMessage(MSG* pMsg)
   // Ctrl + 'key' in Notes
   if (pMsg->message == WM_KEYDOWN &&
       (GetKeyState(VK_CONTROL) & 0x8000)  == 0x8000 &&
-      m_pex_notes->m_hWnd == ::GetFocus()) {
+      m_ex_notes.m_hWnd == ::GetFocus()) {
     switch (pMsg->wParam) {
       case 'A':
         // Ctrl+A (Select All), then SelectAllNotes
@@ -504,7 +502,7 @@ BOOL CAddEdit_Basic::PreTranslateMessage(MSG* pMsg)
         return TRUE;
       case 'V':
         // Ctrl+V (Paste), then do PasteSpecial
-        m_pex_notes->PasteSpecial(CF_UNICODETEXT);
+        m_ex_notes.PasteSpecial(CF_UNICODETEXT);
         return TRUE;
       case VK_ADD:
       case VK_SUBTRACT:
@@ -587,10 +585,10 @@ BOOL CAddEdit_Basic::OnApply()
   }
 
   // If there is a matching entry in our list, tell the user to try again.
-  listindex = M_pDbx()->Find(M_group(), M_title(), M_username());
+  listindex = GetMainDlg()->Find(M_group(), M_title(), M_username());
   if (M_uicaller() == IDS_ADDENTRY) {
     // Add entry
-    if (listindex != M_pDbx()->End()) {
+    if (listindex != GetMainDlg()->End()) {
       CSecString temp;
       if (M_group().IsEmpty())
         if (M_username().IsEmpty())
@@ -609,8 +607,8 @@ BOOL CAddEdit_Basic::OnApply()
     }
   } else {
     // Edit entry
-    if (listindex != M_pDbx()->End()) {
-      const CItemData &listItem = M_pDbx()->GetEntryAt(listindex);
+    if (listindex != GetMainDlg()->End()) {
+      const CItemData &listItem = GetMainDlg()->GetEntryAt(listindex);
       if (listItem.GetUUID() != M_pci()->GetUUID()) {
         CSecString temp;
         temp.Format(IDS_ENTRYEXISTS, M_group(), M_title(), M_username());
@@ -722,8 +720,8 @@ void CAddEdit_Basic::HidePassword()
 void CAddEdit_Basic::SetZoomMenu()
 {
   // If at the limit - don't allow to be called again in that direction
-  m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, m_iPointSize < 72);
-  m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, m_iPointSize > 6);
+  m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, m_iPointSize < 72);
+  m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, m_iPointSize > 6);
 }
 
 LRESULT CAddEdit_Basic::OnZoomNotes(WPARAM, LPARAM lParam)
@@ -739,19 +737,19 @@ LRESULT CAddEdit_Basic::OnZoomNotes(WPARAM, LPARAM lParam)
   WPARAM wp_increment = (lParam > 0 ? 1 : -1) * 2;
 
   long nStart, nEnd;
-  m_pex_notes->GetSel(nStart, nEnd);
+  m_ex_notes.GetSel(nStart, nEnd);
 
-  m_pex_notes->SetSel(0, -1);
-  m_pex_notes->HideSelection(TRUE, FALSE);
-  m_pex_notes->SendMessage(EM_SETFONTSIZE, wp_increment, 0);
+  m_ex_notes.SetSel(0, -1);
+  m_ex_notes.HideSelection(TRUE, FALSE);
+  m_ex_notes.SendMessage(EM_SETFONTSIZE, wp_increment, 0);
 
   CHARFORMAT cf = {0};
   cf.cbSize = sizeof(cf);
 
-  m_pex_notes->SendMessage(EM_GETCHARFORMAT, SCF_SELECTION, (LPARAM)&cf);
+  m_ex_notes.SendMessage(EM_GETCHARFORMAT, SCF_SELECTION, (LPARAM)&cf);
   m_iPointSize = cf.yHeight / 20;
 
-  m_pex_notes->SetSel(nStart, nEnd);
+  m_ex_notes.SetSel(nStart, nEnd);
 
   SetZoomMenu();
   return 0L;
@@ -776,8 +774,8 @@ void CAddEdit_Basic::HideNotes()
     m_notes = HIDDEN_NOTES;
     GetDlgItem(IDC_NOTES)->Invalidate();
     // Disable zoom of hidden text
-    m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, false);
-    m_pex_notes->EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, false);
+    m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMIN, false);
+    m_ex_notes.EnableMenuItem(PWS_MSG_CALL_NOTESZOOMOUT, false);
   }
 }
 
@@ -815,23 +813,23 @@ void CAddEdit_Basic::OnGeneratePassword()
   StringX passwd;
   if (M_ipolicy() == NAMED_POLICY) {
     PWPolicy st_pp;
-    M_pDbx()->GetPolicyFromName(M_policyname(), st_pp);
-    M_pDbx()->MakeRandomPassword(passwd, st_pp);
+    GetMainDlg()->GetPolicyFromName(M_policyname(), st_pp);
+    GetMainDlg()->MakeRandomPassword(passwd, st_pp);
   } else {
     // XXX temp - to be cleaned up
     PWPolicy policy(M_pwp());
     policy.symbols = LPCWSTR(M_symbols());
-    M_pDbx()->MakeRandomPassword(passwd, policy);
+    GetMainDlg()->MakeRandomPassword(passwd, policy);
   }
 
   if (rc == CChangeAliasPswd::CHANGEBASE) {
     // Change Base
-    ItemListIter iter = M_pDbx()->Find(M_base_uuid());
+    ItemListIter iter = GetMainDlg()->Find(M_base_uuid());
     ASSERT(iter != M_pcore()->GetEntryEndIter());
     CItemData *pci = &iter->second;
     Command *pcmd = UpdatePasswordCommand::Create(M_pcore(), *pci,
                                                   passwd);
-    M_pDbx()->Execute(pcmd);
+    GetMainDlg()->Execute(pcmd);
   } else {
     M_realpassword() = m_password = passwd.c_str();
     if (m_isPWHidden) {
@@ -866,7 +864,7 @@ void CAddEdit_Basic::OnENChangeNotes()
 
   // Called for any change - even just clicking on it - so check really changed
   CSecString current_notes;
-  m_pex_notes->GetWindowText(current_notes);
+  m_ex_notes.GetWindowText(current_notes);
   if (current_notes == M_realnotes())
     return;
 
@@ -941,8 +939,8 @@ void CAddEdit_Basic::OnSTCExClicked(UINT nID)
     default:
       ASSERT(0);
   }
-  M_pDbx()->SetClipboardData(cs_data);
-  M_pDbx()->UpdateLastClipboardAction(iaction);
+  GetMainDlg()->SetClipboardData(cs_data);
+  GetMainDlg()->UpdateLastClipboardAction(iaction);
 }
 
 void CAddEdit_Basic::SelectAllNotes()
@@ -955,9 +953,9 @@ void CAddEdit_Basic::SelectAllNotes()
 LRESULT CAddEdit_Basic::OnWordWrap(WPARAM, LPARAM)
 {
   m_bWordWrap = !m_bWordWrap;
-  m_pex_notes->SetTargetDevice(NULL, m_bWordWrap ? 0 : 1);
+  m_ex_notes.SetTargetDevice(NULL, m_bWordWrap ? 0 : 1);
 
-  m_pex_notes->UpdateState(PWS_MSG_EDIT_WORDWRAP, m_bWordWrap);
+  m_ex_notes.UpdateState(PWS_MSG_EDIT_WORDWRAP, m_bWordWrap);
 
   return 0L;
 }
@@ -996,8 +994,8 @@ void CAddEdit_Basic::OnLaunch()
 
   const bool bDoAutoType = (GetKeyState(VK_CONTROL) & 0x8000) != 0;
 
-  M_pDbx()->LaunchBrowser(M_URL(), sx_autotype, vactionverboffsets, bDoAutoType);
-  M_pDbx()->UpdateLastClipboardAction(CItemData::URL);
+  GetMainDlg()->LaunchBrowser(M_URL(), sx_autotype, vactionverboffsets, bDoAutoType);
+  GetMainDlg()->UpdateLastClipboardAction(CItemData::URL);
 
   if (bDoAutoType) {
     // Reset button
@@ -1015,8 +1013,8 @@ void CAddEdit_Basic::OnSendEmail()
 {
   UpdateData(TRUE);
 
-  M_pDbx()->SendEmail(M_email());
-  M_pDbx()->UpdateLastClipboardAction(CItemData::EMAIL);
+  GetMainDlg()->SendEmail(M_email());
+  GetMainDlg()->UpdateLastClipboardAction(CItemData::EMAIL);
 }
 
 LRESULT CAddEdit_Basic::OnCallExternalEditor(WPARAM, LPARAM)
