@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -15,7 +15,6 @@
 #include "AdvancedDlg.h"
 
 #include "core/ItemData.h"
-#include "core/core.h"
 
 #include "resource.h"
 #include "resource3.h"
@@ -41,7 +40,7 @@ int CAdvancedDlg::dialog_lookup[LAST] = {
 CAdvancedDlg::CAdvancedDlg(CWnd* pParent /*=NULL*/, Type iIndex /*=INVALID*/,
                            st_SaveAdvValues *pst_SADV)
   : CPWDialog(dialog_lookup[iIndex], pParent), m_iIndex(iIndex), m_pst_SADV(pst_SADV),
-  m_pToolTipCtrl(NULL), m_treatwhitespaceasempty(BST_CHECKED)
+  m_treatwhitespaceasempty(BST_CHECKED)
 {
   if (m_pst_SADV != NULL) {
     m_bsFields = m_pst_SADV->bsFields;
@@ -73,11 +72,6 @@ CAdvancedDlg::CAdvancedDlg(CWnd* pParent /*=NULL*/, Type iIndex /*=INVALID*/,
     m_bsFields.set();
 }
 
-CAdvancedDlg::~CAdvancedDlg()
-{
-  delete m_pToolTipCtrl;
-}
-
 BOOL CAdvancedDlg::OnInitDialog()
 {
   CPWDialog::OnInitDialog();
@@ -216,17 +210,35 @@ BOOL CAdvancedDlg::OnInitDialog()
     m_bsAllowedFields.set(CItemData::POLICY);
     m_bsDefaultSelectedFields.set(CItemData::POLICY);
 
+    cs_text.LoadString(IDS_POLICYNAME);
+    iItem = m_pLC_Selected->InsertItem(++iItem, cs_text);
+    m_pLC_Selected->SetItemData(iItem, CItemData::POLICYNAME | NORMALFIELD);
+    m_bsAllowedFields.set(CItemData::POLICYNAME);
+    m_bsDefaultSelectedFields.set(CItemData::POLICYNAME);
+
     cs_text.LoadString(IDS_DCALONG);
     iItem = m_pLC_Selected->InsertItem(++iItem, cs_text);
     m_pLC_Selected->SetItemData(iItem, CItemData::DCA | NORMALFIELD);
     m_bsAllowedFields.set(CItemData::DCA);
     m_bsDefaultSelectedFields.set(CItemData::DCA);
 
+    cs_text.LoadString(IDS_SHIFTDCALONG);
+    iItem = m_pLC_Selected->InsertItem(++iItem, cs_text);
+    m_pLC_Selected->SetItemData(iItem, CItemData::SHIFTDCA | NORMALFIELD);
+    m_bsAllowedFields.set(CItemData::SHIFTDCA);
+    m_bsDefaultSelectedFields.set(CItemData::SHIFTDCA);
+
     cs_text.LoadString(IDS_PROTECTED);
     iItem = m_pLC_Selected->InsertItem(++iItem, cs_text);
     m_pLC_Selected->SetItemData(iItem, CItemData::PROTECTED | NORMALFIELD);
     m_bsAllowedFields.set(CItemData::PROTECTED);
     m_bsDefaultSelectedFields.set(CItemData::PROTECTED);
+
+    cs_text.LoadString(IDS_KBSHORTCUT);
+    iItem = m_pLC_Selected->InsertItem(++iItem, cs_text);
+    m_pLC_Selected->SetItemData(iItem, CItemData::KBSHORTCUT | NORMALFIELD);
+    m_bsAllowedFields.set(CItemData::KBSHORTCUT);
+    m_bsDefaultSelectedFields.set(CItemData::KBSHORTCUT);
   }
 
   // Deal with text fields - all selected by default
@@ -380,8 +392,7 @@ END_MESSAGE_MAP()
 
 void CAdvancedDlg::OnHelp()
 {
-  CString cs_HelpTopic = app.GetHelpFileName() + L"::/html/advanced.html";
-  ::HtmlHelp(this->GetSafeHwnd(), (LPCWSTR)cs_HelpTopic, HH_DISPLAY_TOPIC, 0);
+  ShowHelp(L"::/html/advanced.html");
 }
 
 void CAdvancedDlg::OnReset()
@@ -639,17 +650,17 @@ void CAdvancedDlg::OnDeselectAll()
   m_pLC_List->SortItems(AdvCompareFunc, NULL);
 }
 
-void CAdvancedDlg::OnSelectedItemChanging(NMHDR *pNMHDR, LRESULT *pResult)
+void CAdvancedDlg::OnSelectedItemChanging(NMHDR *pNotifyStruct, LRESULT *pLResult)
 {
   // Prevent mandatory fields being deselected
-  NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR; 
+  NMLISTVIEW *pNMListView = (NMLISTVIEW *)pNotifyStruct; 
 
   if (m_bsMandatoryFields.test(pNMListView->lParam & 0xff) &&
       (pNMListView->uNewState & LVIS_SELECTED)) {
     pNMListView->uNewState &= ~LVIS_SELECTED;
-    *pResult = TRUE;
+    *pLResult = TRUE;
   } else
-    *pResult = FALSE;
+    *pLResult = FALSE;
 }
 
 // Override PreTranslateMessage() so RelayEvent() can be
