@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -15,30 +15,28 @@
 #include "DboxMain.h"
 #include "RUEList.h"
 
-#if defined(POCKET_PC)
-#include "pocketpc/resource.h"
-#else
 #include <errno.h>
 #include "resource.h"
 #include "resource2.h"  // Menu, Toolbar & Accelerator resources
 #include "resource3.h"  // String resources
-#endif
 
 #include "core/pwsprefs.h"
 #include "core/pwscore.h"
 #include "core/PWSAuxParse.h"
 
+#include "os/logit.h"
+
 #ifdef _DEBUG
 #define new DEBUG_NEW
 #undef THIS_FILE
 static char THIS_FILE[] = __FILE__;
 #endif
 
-static bool SafeGetBaseEntry(const DboxMain *pDbx, const CItemData &dep, CItemData &base)
+static bool SafeGetBaseEntry(const CItemData &dep, CItemData &base)
 {
   // Asserts in debug build if GetBaseEntry(dependent) fails
   // returns false in release build
-  const CItemData *pBase = pDbx->GetBaseEntry(&dep);
+  const CItemData *pBase = app.GetMainDlg()->GetBaseEntry(&dep);
   ASSERT(pBase != NULL);
   if (pBase != NULL) {
     base = *pBase;
@@ -48,9 +46,10 @@ static bool SafeGetBaseEntry(const DboxMain *pDbx, const CItemData &dep, CItemDa
 }
 
 /////////////////////////////// New System Tray Commands /////////////////////
-#ifndef POCKET_PC
 void DboxMain::OnTrayLockUnLock()
 {
+  PWS_LOGIT;
+
   switch(app.GetSystemTrayState()) {
     case ThisMfcApp::LOCKED:            // User clicked UnLock!
       // This only unlocks the database - it does not restore the window
@@ -90,14 +89,14 @@ void DboxMain::OnTrayCopyUsername(UINT nID)
     return;
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
   const StringX cs_username = ci.GetUser();
   SetClipboardData(cs_username);
   UpdateLastClipboardAction(CItemData::USER);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayCopyUsername(CCmdUI *)
@@ -113,14 +112,14 @@ void DboxMain::OnTrayCopyPassword(UINT nID)
     return;
 
   if (ci.IsDependent()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
   const StringX cs_password = ci.GetPassword();
   SetClipboardData(cs_password);
   UpdateLastClipboardAction(CItemData::PASSWORD);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayCopyPassword(CCmdUI *)
@@ -136,12 +135,12 @@ void DboxMain::OnTrayCopyNotes(UINT nID)
     return;
 
   if (ci.IsShortcut())
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return;
 
   SetClipboardData(ci.GetNotes());
   UpdateLastClipboardAction(CItemData::NOTES);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayCopyNotes(CCmdUI *)
@@ -165,7 +164,7 @@ void DboxMain::OnTrayBrowse(UINT nID)
   }
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return;
   }
 
@@ -174,7 +173,7 @@ void DboxMain::OnTrayBrowse(UINT nID)
     StringX sxAutotype = PWSAuxParse::GetAutoTypeString(ci.GetAutoType(),
                                   ci.GetGroup(), ci.GetTitle(), 
                                   ci.GetUser(), ci.GetPassword(), 
-                                  ci.GetNotes(),
+                                  ci.GetNotes(), ci.GetURL(), ci.GetEmail(),
                                   vactionverboffsets);
 
     LaunchBrowser(ci.GetURL().c_str(), sxAutotype, vactionverboffsets, bDoAutotype);
@@ -182,10 +181,9 @@ void DboxMain::OnTrayBrowse(UINT nID)
     if (PWSprefs::GetInstance()->GetPref(PWSprefs::CopyPasswordWhenBrowseToURL)) {
       SetClipboardData(ci.GetPassword());
       UpdateLastClipboardAction(CItemData::PASSWORD);
-    } else
-      UpdateLastClipboardAction(CItemData::URL);
+    }
   }
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayBrowse(CCmdUI *pCmdUI)
@@ -207,7 +205,7 @@ void DboxMain::OnUpdateTrayBrowse(CCmdUI *pCmdUI)
   }
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return;
   }
 
@@ -243,14 +241,14 @@ void DboxMain::OnTrayCopyEmail(UINT nID)
     return;
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
   const StringX cs_email = ci.GetEmail();
   SetClipboardData(cs_email);
   UpdateLastClipboardAction(CItemData::EMAIL);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayCopyEmail(CCmdUI *)
@@ -266,7 +264,7 @@ void DboxMain::OnTraySendEmail(UINT nID)
       return;
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
@@ -281,7 +279,7 @@ void DboxMain::OnTraySendEmail(UINT nID)
   if (!cs_command.IsEmpty()) {
     std::vector<size_t> vactionverboffsets;
     LaunchBrowser(cs_command, L"", vactionverboffsets, false);
-    UpdateAccessTime(&ci);
+    UpdateAccessTime(ci.GetUUID());
   }
 }
 
@@ -333,7 +331,7 @@ void DboxMain::OnTrayAutoType(UINT nID)
 
   m_bInAT = true;
   AutoType(ci);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
   m_bInAT = false;
 }
 
@@ -350,7 +348,7 @@ void DboxMain::OnTrayCopyURL(UINT nID)
     return;
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
@@ -368,7 +366,7 @@ void DboxMain::OnTrayCopyURL(UINT nID)
 
   SetClipboardData(cs_URL);
   UpdateLastClipboardAction(CItemData::URL);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayCopyURL(CCmdUI *)
@@ -384,7 +382,7 @@ void DboxMain::OnTrayRunCommand(UINT nID)
     return;
 
   if (ci.IsShortcut()) {
-    if (!SafeGetBaseEntry(this, ci, ci))
+    if (!SafeGetBaseEntry(ci, ci))
       return; // fail safely in release
   }
 
@@ -402,11 +400,9 @@ void DboxMain::OnTrayRunCommand(UINT nID)
 
   SetClipboardData(cs_URL);
   UpdateLastClipboardAction(CItemData::URL);
-  UpdateAccessTime(&ci);
+  UpdateAccessTime(ci.GetUUID());
 }
 
 void DboxMain::OnUpdateTrayRunCommand(CCmdUI *)
 {
 }
-
-#endif /*  POCKET_PC */
