@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2012 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -444,7 +444,6 @@ void DboxMain::OnDuplicateGroup()
           continue;
         }
 
-        TRACE(L"Copying %s.%s\n", pci->GetGroup().c_str(), pci->GetTitle().c_str());
         // Set up copy
         CItemData ci2(*pci);
         ci2.SetDisplayInfo(NULL);
@@ -458,6 +457,9 @@ void DboxMain::OnDuplicateGroup()
         const StringX sxThisEntryNewGroup = sxNewPath + subPath;
         ci2.SetGroup(sxThisEntryNewGroup);
 
+        // Remove any keyboard shortcut otherwise it will be doubly assigned (not allowed!)
+        ci2.SetKBShortcut(0);
+
         if (pci->IsBase()) {
           mapOldToNewBaseUUIDs.insert(std::make_pair(pci->GetUUID(),
                                                      ci2.GetUUID()));
@@ -493,6 +495,10 @@ void DboxMain::OnDuplicateGroup()
           ci2.CreateUUID();
           ci2.SetStatus(CItemData::ES_ADDED);
           ci2.SetProtected(false);
+
+          // Remove any keyboard shortcut otherwise it will be doubly assigned (not allowed!)
+          ci2.SetKBShortcut(0);
+
           // Set new group
           StringX subPath =  pci->GetGroup();
           ASSERT(subPath.length() >= grplen);
@@ -784,10 +790,6 @@ void DboxMain::OnDelete()
   if (m_core.GetNumEntries() == 0) // easiest way to avoid asking stupid questions...
     return;
 
-  // Ignore if more than one selected - List view only
-  if (m_ctlItemList.GetSelectedCount() > 1)
-    return;
-
   bool bAskForDeleteConfirmation = !(PWSprefs::GetInstance()->
                                      GetPref(PWSprefs::DeleteQuestion));
   bool dodelete = true;
@@ -808,6 +810,9 @@ void DboxMain::OnDelete()
       }
     }
   } else {
+    // Ignore if more than one selected - List view only
+    if (m_ctlItemList.GetSelectedCount() > 1)
+      return;
     POSITION pos = m_ctlItemList.GetFirstSelectedItemPosition();
     if (pos != NULL) {
       pci = (CItemData *)m_ctlItemList.GetItemData((int)pos - 1);
@@ -978,11 +983,15 @@ void DboxMain::OnEdit()
   if (SelItemOk() == TRUE) {
     CItemData *pci = getSelectedItem();
     ASSERT(pci != NULL);
-
-    if (pci->IsShortcut())
-      EditShortcut(pci);
-    else
-      EditItem(pci);
+    try {
+      if (pci->IsShortcut())
+        EditShortcut(pci);
+      else
+        EditItem(pci);
+    } catch (CString err) {
+      CGeneralMsgBox gmb;
+      gmb.MessageBox(err, NULL, MB_OK | MB_ICONERROR);
+    }
   } else {
     // entry item not selected - perhaps here on Enter on tree item?
     // perhaps not the most elegant solution to improving non-mouse use,
@@ -1222,6 +1231,7 @@ void DboxMain::UpdateEntry(CAddEdit_PropertySheet *pentry_psh)
   SetChanged(Data);
 
   ChangeOkUpdate();
+
   // Order may have changed as a result of edit
   m_ctlItemTree.SortTree(TVI_ROOT);
   SortListView();
@@ -1351,6 +1361,9 @@ void DboxMain::OnDuplicateEntry()
     ci2.SetStatus(CItemData::ES_ADDED);
     ci2.SetProtected(false);
 
+    // Remove any keyboard shortcut otherwise it will be doubly assigned (not allowed!)
+    ci2.SetKBShortcut(0);
+
     Command *pcmd = NULL;
     if (pci->IsDependent()) {
       if (pci->IsAlias()) {
@@ -1473,7 +1486,7 @@ void DboxMain::CopyDataToClipBoard(const CItemData::FieldType ft, const bool bSp
 
   const pws_os::CUUID uuid = pci->GetUUID();
 
-  if (pci->IsShortcut() ||
+  if ((pci->IsShortcut() && ft != CItemData::USER) ||
       (pci->IsAlias() && ft == CItemData::PASSWORD)) {
     CItemData *pbci = GetBaseEntry(pci);
     ASSERT(pbci != NULL);
@@ -1801,9 +1814,14 @@ void DboxMain::OnRunCommand()
     return;
   }
 
+  // if no autotype value in run command's $a(value), start with item's (bug #1078)
+  if (m_sxAutoType.empty())
+    m_sxAutoType = pci->GetAutoType();
+
   m_sxAutoType = PWSAuxParse::GetAutoTypeString(m_sxAutoType, pci->GetGroup(),
                                  pci->GetTitle(), pci->GetUser(),
                                  sx_pswd, pci->GetNotes(),
+                                 pci->GetURL(), pci->GetEmail(),
                                  m_vactionverboffsets);
   SetClipboardData(pci->GetPassword());
   UpdateLastClipboardAction(CItemData::PASSWORD);
@@ -2023,6 +2041,17 @@ void DboxMain::AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup)
       }
     }
     ci_temp.SetStatus(CItemData::ES_ADDED);
+    
+    // Need to check that entry keyboard shortcut not already in use!
+    int32 iKBShortcut;
+    ci_temp.GetKBShortcut(iKBShortcut);
+    
+    if (iKBShortcut != 0 && 
+      m_core.GetKBShortcut(iKBShortcut) != CUUID::NullUUID()) {
+      // Remove it but no mechanism to tell user!
+      ci_temp.SetKBShortcut(0);
+    }
+
     // Add to pwlist
     Command *pcmd = AddEntryCommand::Create(&m_core, ci_temp);
     if (!bAddToViews) {
