@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -18,13 +18,9 @@
 #include "GeneralMsgBox.h"
 #include "PWFileDialog.h"
 
-#if defined(POCKET_PC)
-#include "pocketpc/resource.h"
-#else
 #include "resource.h"
 #include "resource2.h"  // Menu, Toolbar & Accelerator resources
 #include "resource3.h"  // String resources
-#endif
 
 #include "filter/SetFiltersDlg.h"
 #include "filter/ManageFiltersDlg.h"
@@ -49,6 +45,20 @@ using namespace std;
 static char THIS_FILE[] = __FILE__;
 #endif
 
+void DboxMain::OnCancelFilter()
+{
+  // Deal with the 2 internal filters before user defined ones
+  if (m_bExpireDisplayed) {
+    OnShowExpireList();
+  } else
+  if (m_bUnsavedDisplayed) {
+    OnShowUnsavedEntries();
+  } else
+  if (m_bFilterActive) {
+    ApplyFilter();
+  }
+}
+
 void DboxMain::OnApplyFilter()
 {
   ApplyFilter();
@@ -234,6 +244,7 @@ bool DboxMain::PassesFiltering(const CItemData &ci,
         case FT_RUNCMD:
         case FT_EMAIL:
         case FT_SYMBOLS:
+        case FT_POLICYNAME:
           mt = PWSMatch::MT_STRING;
           break;
         case FT_PASSWORD:
@@ -242,6 +253,9 @@ bool DboxMain::PassesFiltering(const CItemData &ci,
         case FT_DCA:
           mt = PWSMatch::MT_DCA;
           break;
+        case FT_SHIFTDCA:
+          mt = PWSMatch::MT_SHIFTDCA;
+          break;
         case FT_CTIME:
         case FT_PMTIME:
         case FT_ATIME:
@@ -258,6 +272,10 @@ bool DboxMain::PassesFiltering(const CItemData &ci,
         case FT_XTIME_INT:
           mt = PWSMatch::MT_INTEGER;
           break;
+        case FT_KBSHORTCUT:
+          bValue = !ci.GetKBShortcut().empty();
+          mt = PWSMatch::MT_BOOL;
+          break;
         case FT_UNKNOWNFIELDS:
           bValue = ci.NumberUnknownFields() > 0;
           mt = PWSMatch::MT_BOOL;
@@ -266,6 +284,9 @@ bool DboxMain::PassesFiltering(const CItemData &ci,
           bValue = ci.IsProtected();
           mt = PWSMatch::MT_BOOL;
           break;
+        case FT_PASSWORDLEN:
+          mt = PWSMatch::MT_INTEGER;
+          break;
         case FT_ENTRYTYPE:
           mt = PWSMatch::MT_ENTRYTYPE;
           break;
@@ -359,7 +380,8 @@ bool DboxMain::PassesFiltering(const CItemData &ci,
           tests++;
           break;
         case PWSMatch::MT_DCA:
-          thistest_rc = pci->Matches(st_fldata.fdca, ifunction);
+        case PWSMatch::MT_SHIFTDCA:
+          thistest_rc = pci->Matches(st_fldata.fdca, ifunction, mt == PWSMatch::MT_SHIFTDCA);
           tests++;
           break;
         case PWSMatch::MT_ENTRYSTATUS:
@@ -405,7 +427,7 @@ bool DboxMain::PassesPWHFiltering(const CItemData *pci,
 
   bool status = CreatePWHistoryList(pci->GetPWHistory(),
                                     pwh_max, err_num,
-                                    pwhistlist, TMC_EXPORT_IMPORT);
+                                    pwhistlist, PWSUtil::TMC_EXPORT_IMPORT);
 
   bPresent = pwh_max > 0 || !pwhistlist.empty();
 
@@ -573,18 +595,18 @@ bool DboxMain::PassesPWPFiltering(const CItemData *pci,
           mt = PWSMatch::MT_INTEGER;
           break;
         case PT_HEXADECIMAL:
-          bValue = (pwp.flags & PWSprefs::PWPolicyUseHexDigits) ==
-                       PWSprefs::PWPolicyUseHexDigits;
+          bValue = (pwp.flags & PWPolicy::UseHexDigits) ==
+                       PWPolicy::UseHexDigits;
           mt = PWSMatch::MT_BOOL;
           break;
         case PT_EASYVISION:
-          bValue = (pwp.flags & PWSprefs::PWPolicyUseEasyVision) ==
-                       PWSprefs::PWPolicyUseEasyVision;
+          bValue = (pwp.flags & PWPolicy::UseEasyVision) ==
+                       PWPolicy::UseEasyVision;
           mt = PWSMatch::MT_BOOL;
           break;
         case PT_PRONOUNCEABLE:
-          bValue = (pwp.flags & PWSprefs::PWPolicyMakePronounceable) ==
-                       PWSprefs::PWPolicyMakePronounceable;
+          bValue = (pwp.flags & PWPolicy::MakePronounceable) ==
+                       PWPolicy::MakePronounceable;
           mt = PWSMatch::MT_BOOL;
           break;
         default:
@@ -763,7 +785,6 @@ void DboxMain::ImportFilters()
   const std::wstring XSDfn(L"pwsafe_filter.xsd");
   std::wstring XSDFilename = PWSdirs::GetXMLDir() + XSDfn;
 
-#if USE_XML_LIBRARY == MSXML || USE_XML_LIBRARY == XERCES
   if (!pws_os::FileExists(XSDFilename)) {
     CGeneralMsgBox gmb;
     cs_temp.Format(IDSC_MISSINGXSD, XSDfn.c_str());
@@ -771,7 +792,6 @@ void DboxMain::ImportFilters()
     gmb.MessageBox(cs_temp, cs_title, MB_OK | MB_ICONSTOP);
     return;
   }
-#endif
 
   std::wstring dir;
   if (m_core.GetCurFile().empty())
