@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -24,7 +24,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 CSHCTListCtrl::CSHCTListCtrl()
-: m_pParent(NULL), m_pHotKey(NULL), m_pchTip(NULL), m_pwchTip(NULL),
+: m_pParent(NULL), m_pHotKey(NULL), m_pwchTip(NULL),
   m_bHotKeyActive(false)
 {
   m_pHotKey = new CSHCTHotKey;
@@ -36,20 +36,19 @@ CSHCTListCtrl::~CSHCTListCtrl()
 {
   m_pHotKey->DestroyWindow();
   delete m_pHotKey;
-  delete m_pchTip;
   delete m_pwchTip;
 }
 
 BEGIN_MESSAGE_MAP(CSHCTListCtrl, CListCtrl)
   //{{AFX_MSG_MAP(CSHCTListCtrl)
-  ON_NOTIFY_EX_RANGE(TTN_NEEDTEXTW, 0, 0xFFFF, OnToolTipText)
-  ON_NOTIFY_EX_RANGE(TTN_NEEDTEXTA, 0, 0xFFFF, OnToolTipText)
-  ON_NOTIFY_REFLECT(NM_CUSTOMDRAW, OnCustomDraw)
   ON_WM_LBUTTONDOWN()
   ON_WM_RBUTTONDOWN()
   ON_WM_HSCROLL()
   ON_WM_VSCROLL()
   ON_WM_MOUSEWHEEL()
+
+  ON_NOTIFY_REFLECT(NM_CUSTOMDRAW, OnCustomDraw)
+  ON_NOTIFY_EX_RANGE(TTN_NEEDTEXTW, 0, 0xFFFF, OnToolTipText)
   //}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
@@ -99,7 +98,7 @@ void CSHCTListCtrl::OnLButtonDown(UINT , CPoint point)
   m_id = (UINT)LOWORD(GetItemData(m_item));
   if (m_pParent->GetMapMenuShortcutsIter(m_id, iter)) {
     WORD vModifiers = iter->second.cModifier;
-    m_pHotKey->SetHotKey(iter->second.cVirtKey, vModifiers);
+    m_pHotKey->SetHotKey(iter->second.siVirtKey, vModifiers);
   }
   m_pHotKey->EnableWindow(TRUE);
   m_pHotKey->ShowWindow(SW_SHOW);
@@ -142,11 +141,11 @@ void CSHCTListCtrl::OnRButtonDown(UINT , CPoint point)
 
   PopupMenu.LoadMenu(IDR_POPRESETSHORTCUT);
   CMenu* pContextMenu = PopupMenu.GetSubMenu(0);
-  if (iter->second.cVirtKey == 0)
+  if (iter->second.siVirtKey == 0)
     pContextMenu->RemoveMenu(ID_MENUITEM_REMOVESHORTCUT, MF_BYCOMMAND);
 
-  if (iter->second.cVirtKey   == iter->second.cdefVirtKey &&
-      iter->second.cModifier  == iter->second.cdefModifier)
+  if (iter->second.siVirtKey   == iter->second.siDefVirtKey &&
+      iter->second.cModifier  == iter->second.cDefModifier)
     pContextMenu->RemoveMenu(ID_MENUITEM_RESETSHORTCUT, MF_BYCOMMAND);
 
   if (pContextMenu->GetMenuItemCount() == 0)
@@ -159,8 +158,8 @@ void CSHCTListCtrl::OnRButtonDown(UINT , CPoint point)
                                          pt.x, pt.y, this);
 
   if (nID == ID_MENUITEM_REMOVESHORTCUT) {
-    iter->second.cVirtKey = (unsigned char)0;
-    iter->second.cModifier = (unsigned char)0;
+    iter->second.siVirtKey = 0;
+    iter->second.cModifier = 0;
     str = L"";
     goto update;
   }
@@ -168,8 +167,8 @@ void CSHCTListCtrl::OnRButtonDown(UINT , CPoint point)
   if (nID != ID_MENUITEM_RESETSHORTCUT)
     goto exit;
 
-  iter->second.cVirtKey = iter->second.cdefVirtKey;
-  iter->second.cModifier = iter->second.cdefModifier;
+  iter->second.siVirtKey = iter->second.siDefVirtKey;
+  iter->second.cModifier = iter->second.cDefModifier;
 
   str = CMenuShortcut::FormatShortcut(iter);
 
@@ -189,21 +188,21 @@ exit:
 void CSHCTListCtrl::SaveHotKey()
 {
   if (m_bHotKeyActive) {
-    WORD wVK, wMod;
-    m_pHotKey->GetHotKey(wVK, wMod);
-    OnHotKeyKillFocus(wVK, wMod);
+    WORD wVirtualKeyCode, wHKModifiers;
+    m_pHotKey->GetHotKey(wVirtualKeyCode, wHKModifiers);
+    OnMenuShortcutKillFocus(wVirtualKeyCode, wHKModifiers);
   }
 }
 
-void CSHCTListCtrl::OnHotKeyKillFocus(const WORD wVirtualKeyCode, 
-                                      const WORD wModifiers)
+void CSHCTListCtrl::OnMenuShortcutKillFocus(const WORD wVirtualKeyCode, 
+                                          const WORD wHKModifiers)
 {
   m_pHotKey->EnableWindow(FALSE);
   m_pHotKey->ShowWindow(SW_HIDE);
 
   if (m_pParent != NULL) {
-    m_pParent->OnHotKeyKillFocus(m_item, m_id, 
-                                 wVirtualKeyCode, wModifiers);
+    m_pParent->OnMenuShortcutKillFocus(m_item, m_id, 
+                                 wVirtualKeyCode, wHKModifiers);
   }
 
   m_bHotKeyActive = false;
@@ -253,7 +252,7 @@ void CSHCTListCtrl::OnCustomDraw(NMHDR *pNotifyStruct, LRESULT *pLResult)
       switch (iSubItem) {
         case SHCT_MENUITEMTEXT:
           if ( m_pParent->GetMapMenuShortcutsIter(id, iter) && 
-              ( (iter->second.cVirtKey != iter->second.cdefVirtKey) || (iter->second.cModifier != iter->second.cdefModifier) ))
+              ( (iter->second.siVirtKey != iter->second.siDefVirtKey) || (iter->second.cModifier != iter->second.cDefModifier) ))
             pLVCD->clrText = m_crRedText;
           break;
         case SHCT_SHORTCUTKEYS:
@@ -309,9 +308,7 @@ BOOL CSHCTListCtrl::OnToolTipText(UINT /*id*/, NMHDR *pNotifyStruct, LRESULT *pL
     return TRUE;  // do not allow display of automatic tooltip,
                   // or our tooltip will disappear
 
-  // handle both ANSI and UNICODE versions of the message
-  TOOLTIPTEXTA* pTTTA = (TOOLTIPTEXTA*)pNotifyStruct;
-  TOOLTIPTEXTW* pTTTW = (TOOLTIPTEXTW*)pNotifyStruct;
+  TOOLTIPTEXTW *pTTTW = (TOOLTIPTEXTW *)pNotifyStruct;
 
   *pLResult = 0;
 
@@ -354,50 +351,12 @@ BOOL CSHCTListCtrl::OnToolTipText(UINT /*id*/, NMHDR *pNotifyStruct, LRESULT *pL
 
     CString cs_TipText(MAKEINTRESOURCE(nID));
 
-#define LONG_TOOLTIPS
+    delete m_pwchTip;
 
-#ifdef LONG_TOOLTIPS
-    if (pNotifyStruct->code == TTN_NEEDTEXTA) {
-      delete m_pchTip;
-
-      m_pchTip = new char[cs_TipText.GetLength() + 1];
-#if (_MSC_VER >= 1400)
-      size_t num_converted;
-      wcstombs_s(&num_converted, m_pchTip, cs_TipText.GetLength() + 1, cs_TipText,
-                 cs_TipText.GetLength() + 1);
-#else
-      wcstombs(m_pchTip, cs_TipText, cs_TipText.GetLength() + 1);
-#endif
-      pTTTA->lpszText = (LPSTR)m_pchTip;
-    } else {
-      delete m_pwchTip;
-
-      m_pwchTip = new WCHAR[cs_TipText.GetLength() + 1];
-#if (_MSC_VER >= 1400)
-      wcsncpy_s(m_pwchTip, cs_TipText.GetLength() + 1,
+    m_pwchTip = new WCHAR[cs_TipText.GetLength() + 1];
+    wcsncpy_s(m_pwchTip, cs_TipText.GetLength() + 1,
                 cs_TipText, _TRUNCATE);
-#else
-      wcsncpy(m_pwchTip, cs_TipText, cs_TipText.GetLength() + 1);
-#endif
-      pTTTW->lpszText = (LPWSTR)m_pwchTip;
-    }
-#else // Short Tooltips!
-    if (pNotifyStruct->code == TTN_NEEDTEXTA) {
-      int n = WideCharToMultiByte(CP_ACP, 0, cs_TipText, -1,
-                                  pTTTA->szText,
-                                  _countof(pTTTA->szText),
-                                  NULL, NULL);
-      if (n > 0)
-        pTTTA->szText[n - 1] = 0;
-    } else {
-#if (_MSC_VER >= 1400)
-      wcsncpy_s(pTTTW->szText, _countof(pTTTW->szText)),
-                cs_TipText, _TRUNCATE);
-#else
-      wcsncpy(pTTTW->szText, cs_TipText, _countof(pTTTW->szText));
-#endif
-    }
-#endif // Long/short tooltips
+    pTTTW->lpszText = (LPWSTR)m_pwchTip;
 
     return TRUE;   // we found a tool tip,
   }
