@@ -29,7 +29,7 @@ CViewReport::CViewReport(CWnd* pParent /*=NULL*/,
   m_pString = m_pRpt->GetString(); 
   Replace(m_pString, sxCRLF, sxLF);
   Replace(m_pString, sxLF, sxCRLF);
-  
+
   m_dwDatasize = (DWORD)(m_pString.length() * sizeof(wchar_t));
 
   m_backgroundcolour = RGB(255, 255, 255);
@@ -165,9 +165,7 @@ void CViewReport::Save()
 
 void CViewReport::SendToClipboard()
 {
-  DboxMain *pDbx = dynamic_cast<DboxMain *>(GetParent());
-  if (pDbx != NULL)
-    pDbx->SetClipboardData(m_pString);
+  GetMainDlg()->SetClipboardData(m_pString);
 }
 
 void CViewReport::Finish()
