@@ -800,6 +800,11 @@ bool CPWFilterLC::SetField(const int iItem)
           m_fbool.m_bt = CFilterBoolDlg::BT_IS;
           mt = PWSMatch::MT_BOOL;
           break;
+        case FT_KBSHORTCUT:
+          // 'Add Present' not needed - bool match
+          m_fbool.m_bt = CFilterBoolDlg::BT_PRESENT;
+          mt = PWSMatch::MT_BOOL;
+          break;
         case FT_UNKNOWNFIELDS:
           // 'Add Present' not needed - bool match
           m_fbool.m_bt = CFilterBoolDlg::BT_PRESENT;
@@ -1507,6 +1512,10 @@ void CPWFilterLC::SetUpComboBoxData()
         stf.ftype = FT_PASSWORDLEN;
         vFcbx_data.push_back(stf);
 
+        stf.cs_text.LoadString(IDS_KBSHORTCUT);
+        stf.ftype = FT_KBSHORTCUT;
+        vFcbx_data.push_back(stf);
+
         stf.cs_text.LoadString(IDS_ENTRYTYPE);
         stf.cs_text.TrimRight(L'\t');
         stf.ftype = FT_ENTRYTYPE;
