@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+ * Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -30,6 +30,13 @@ public:
   ComparisonGrid(wxWindow* parent, wxWindowID id);
   wxPen GetRowGridLinePen(int row);
   bool IsRowSelected(int row) const;
+
+  // Make sure the two rows holding corresponding items from current and comparison db are
+  // always selected together
+  void OnGridRangeSelect(wxGridRangeSelectEvent& evt);
+  void OnAutoSelectGridRow(wxCommandEvent& evt);
+
+  DECLARE_EVENT_TABLE()
 };
 
 
