@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2012 Rony Shapiro <ronys@users.sourceforge.net>.
+ * Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -31,7 +31,7 @@
 #include "core/PWHistory.h"
 #include "core/UIinterface.h"
 #include "os/run.h"
- 
+
 #include "addeditpropsheet.h"
 #include "pwsclip.h"
 #include "./wxutils.h"
@@ -44,7 +44,6 @@
 ////@begin XPM images
 ////@end XPM images
 
-
 /*!
  * AddEditPropSheet type definition
  */
@@ -107,7 +106,6 @@ BEGIN_EVENT_TABLE( AddEditPropSheet, wxPropertySheetDialog )
   EVT_BUTTON( ID_BUTTON1,    AddEditPropSheet::OnClearPWHist )
 END_EVENT_TABLE()
 
-
 /*!
  * AddEditPropSheet constructors
  */
@@ -145,7 +143,6 @@ AddEditPropSheet::AddEditPropSheet(wxWindow* parent, PWScore &core,
   Create(parent, id, dlgTitle, pos, size, style);
 }
 
-
 /*!
  * AddEditPropSheet creator
  */
@@ -226,7 +223,6 @@ void AddEditPropSheet::Init()
 ////@end AddEditPropSheet member initialisation
 }
 
-
 class PolicyValidator : public MultiCheckboxValidator
 {
 public:
@@ -261,6 +257,8 @@ void AddEditPropSheet::CreateControls()
 ////@begin AddEditPropSheet content construction
   AddEditPropSheet* itemPropertySheetDialog1 = this;
 
+  UNREFERENCED_PARAMETER(itemPropertySheetDialog1); // Remove MS Compiler warning
+
   m_BasicPanel = new wxPanel( GetBookCtrl(), ID_PANEL_BASIC, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxTAB_TRAVERSAL );
   wxBoxSizer* itemBoxSizer3 = new wxBoxSizer(wxVERTICAL);
   m_BasicPanel->SetSizer(itemBoxSizer3);
@@ -386,7 +384,7 @@ void AddEditPropSheet::CreateControls()
   m_DCAcomboBoxStrings.Add(_("Copy Password"));
   m_DCAcomboBoxStrings.Add(_("Copy Password + Minimize"));
   m_DCAcomboBoxStrings.Add(_("Copy Username"));
-  m_DCAcomboBoxStrings.Add(_("View/Edit Entry"));
+  m_DCAcomboBoxStrings.Add(_("Edit/View Entry"));
   m_DCAcomboBoxStrings.Add(_("Execute Run command"));
   m_DCAcomboBox = new wxComboBox( itemPanel38, ID_COMBOBOX, wxEmptyString, wxDefaultPosition, wxDefaultSize, m_DCAcomboBoxStrings, wxCB_READONLY );
   itemFlexGridSizer40->Add(m_DCAcomboBox, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL|wxALL, 5);
@@ -402,7 +400,7 @@ void AddEditPropSheet::CreateControls()
   m_SDCAcomboBoxStrings.Add(_("Copy Password"));
   m_SDCAcomboBoxStrings.Add(_("Copy Password + Minimize"));
   m_SDCAcomboBoxStrings.Add(_("Copy Username"));
-  m_SDCAcomboBoxStrings.Add(_("View/Edit Entry"));
+  m_SDCAcomboBoxStrings.Add(_("Edit/View Entry"));
   m_SDCAcomboBoxStrings.Add(_("Execute Run command"));
   m_SDCAcomboBox = new wxComboBox( itemPanel38, ID_COMBOBOX2, wxEmptyString, wxDefaultPosition, wxDefaultSize, m_SDCAcomboBoxStrings, wxCB_READONLY );
   itemFlexGridSizer40->Add(m_SDCAcomboBox, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL|wxALL, 5);
@@ -692,7 +690,6 @@ void AddEditPropSheet::CreateControls()
   FindWindow(IDC_STATIC_DEFAULT_SYMBOLS)->SetLabel(sx_symbols.c_str());
 }
 
-
 /*!
  * Should we show tooltips?
  */
@@ -812,7 +809,7 @@ static struct {short pv; wxString name;}
     {PWSprefs::DoubleClickCopyPassword, _("Copy Password")},
     {PWSprefs::DoubleClickCopyPasswordMinimize, _("Copy Password + Minimize")},
     {PWSprefs::DoubleClickCopyUsername, _("Copy Username")},
-    {PWSprefs::DoubleClickViewEdit, _("View/Edit Entry")},
+    {PWSprefs::DoubleClickViewEdit, _("Edit/View Entry")},
     {PWSprefs::DoubleClickRun, _("Execute Run command")},
    };
 
@@ -836,13 +833,13 @@ static struct {short pv; wxString name;}
   // - Adds " (default)" to default string
   // - Selects current value
   for (size_t i = 0; i < sizeof(dcaMapping)/sizeof(dcaMapping[0]); i++) {
-    pcbox->SetClientData(i, (void *)dcaMapping[i].pv);
+    pcbox->SetClientData(i, reinterpret_cast<void *>(dcaMapping[i].pv));
     if (dcaMapping[i].pv == defDCA) {
       wxString dv = dcaMapping[i].name;
       dv += _(" ("); dv += _("default"); dv += _(")");
       pcbox->SetString(i, dv);
     }
-    if (iDCA == dcaMapping[i].pv) 
+    if (iDCA == dcaMapping[i].pv)
       pcbox->SetValue(dcaMapping[i].name);
   }
 }
@@ -892,7 +889,7 @@ void AddEditPropSheet::ItemFieldsToPropSheet()
   wxWindow *sendBtn = FindWindow(ID_SEND_BTN);
 #ifdef NOTYET
   sendBtn->Enable(!m_email.empty());
-#endif 
+#endif
   // XXX since PWSRun not yet implemented in Linux, Send button's always disabled:
   sendBtn->Enable(false);
   m_notes = (m_type != ADD && m_isNotesHidden) ?
@@ -908,6 +905,8 @@ void AddEditPropSheet::ItemFieldsToPropSheet()
   m_runcmd = m_item.GetRunCommand().c_str();
 
   // double-click actions:
+  m_item.GetDCA(m_DCA, false);
+  m_item.GetDCA(m_ShiftDCA, true);
   SetupDCAComboBoxes(m_DCAcomboBox, m_DCA, false);
   SetupDCAComboBoxes(m_SDCAcomboBox, m_ShiftDCA, true);
 
@@ -932,7 +931,7 @@ void AddEditPropSheet::ItemFieldsToPropSheet()
         m_PWHgrid->AppendRows(pwhl.size() - m_PWHgrid->GetNumberRows());
       }
       m_maxPWHist = int(pwh_max);
-      //reverse-sort the history entries so that we list the newest first 
+      //reverse-sort the history entries so that we list the newest first
       std::sort(pwhl.begin(), pwhl.end(), newer());
       int row = 0;
       for (PWHistList::iterator iter = pwhl.begin(); iter != pwhl.end();
@@ -1004,6 +1003,8 @@ void AddEditPropSheet::ItemFieldsToPropSheet()
     m_cbxPolicyNames->Append(sviter->c_str());
   // Does item use a named policy or item-specific policy?
   bool namedPwPolicy = !m_item.GetPolicyName().empty();
+  UNREFERENCED_PARAMETER(namedPwPolicy); // Remove MS Compiler warning
+
   bool specificPwPolicy = !m_item.GetPWPolicy().empty();
   ASSERT(!(namedPwPolicy && specificPwPolicy)); // both cannot be true!
   m_defPWPRB->SetValue(!specificPwPolicy);
@@ -1020,7 +1021,7 @@ void AddEditPropSheet::ItemFieldsToPropSheet()
     const wxString itemPolName = m_item.GetPolicyName().c_str();
     if (!itemPolName.IsEmpty()) {
       m_cbxPolicyNames->SetValue(itemPolName);
-      m_core.GetPolicyFromName(itemPolName.c_str(), policy);
+      m_core.GetPolicyFromName(tostringx(itemPolName), policy);
     } else {
       m_cbxPolicyNames->SetValue(_("Default Policy"));
       policy = prefs->GetDefaultPolicy();
@@ -1131,19 +1132,17 @@ void AddEditPropSheet::HidePassword()
   m_Password2Ctrl->Enable(true);
 }
 
-static short GetSelectedDCA(wxComboBox *pcbox, short defval)
+static void GetSelectedDCA(const wxComboBox *pcbox, short &val,
+                           short lastval, short defval)
 {
   int sel = pcbox->GetSelection();
-  intptr_t retval = -1;
-  if (sel == wxNOT_FOUND) { // no selection - is this possible with our combobox?
-    goto done;
+  intptr_t ival = -1;
+  if (sel == wxNOT_FOUND) { // no selection
+    val = (lastval == defval) ? -1 : lastval;
   } else {
-    retval = reinterpret_cast<intptr_t>(pcbox->GetClientData(sel));
+    ival = reinterpret_cast<intptr_t>(pcbox->GetClientData(sel));
+    val = (ival == defval) ? -1 : ival;
   }
-  if (retval == defval)
-    retval = -1;
- done:
-  return retval;
 }
 
 void AddEditPropSheet::OnOk(wxCommandEvent& /* evt */)
@@ -1179,14 +1178,14 @@ void AddEditPropSheet::OnOk(wxCommandEvent& /* evt */)
     case EDIT: {
       bool bIsModified, bIsPSWDModified;
       short lastDCA, lastShiftDCA;
+      const PWSprefs *prefs = PWSprefs::GetInstance();
       m_item.GetDCA(lastDCA);
-      m_DCA = GetSelectedDCA(m_DCAcomboBox,
-			     short(PWSprefs::GetInstance()->GetPref(PWSprefs::DoubleClickAction)));
-      
-      m_item.GetShiftDCA(lastShiftDCA);
-      m_ShiftDCA = GetSelectedDCA(m_SDCAcomboBox,
-			     short(PWSprefs::GetInstance()->GetPref(PWSprefs::ShiftDoubleClickAction)));
+      GetSelectedDCA(m_DCAcomboBox, m_DCA, lastDCA,
+                     short(prefs->GetPref(PWSprefs::DoubleClickAction)));
 
+      m_item.GetShiftDCA(lastShiftDCA);
+      GetSelectedDCA(m_SDCAcomboBox, m_ShiftDCA, lastShiftDCA,
+                     short(prefs->GetPref(PWSprefs::ShiftDoubleClickAction)));
       // Check if modified
       int lastXTimeInt;
       m_item.GetXTimeInt(lastXTimeInt);
@@ -1202,7 +1201,7 @@ void AddEditPropSheet::OnOk(wxCommandEvent& /* evt */)
       // Create a new PWHistory string based on settings in this dialog, and compare it
       // with the PWHistory string from the item being edited, to see if the user modified it.
       // Note that we are not erasing the history here, even if the user has chosen to not
-      // track PWHistory.  So there could be some password entries in the history 
+      // track PWHistory.  So there could be some password entries in the history
       // but the first byte could be zero, meaning we are not tracking it _FROM_NOW_.
       // Clearing the history is something the user must do himself with the "Clear History" button
 
@@ -1283,7 +1282,7 @@ void AddEditPropSheet::OnOk(wxCommandEvent& /* evt */)
         } else {
           m_item.SetPWPolicy(pwp);
         }
-        m_item.SetPolicyName(polName.c_str());
+        m_item.SetPolicyName(tostringx(polName));
         m_item.SetDCA(m_DCA);
         m_item.SetShiftDCA(m_ShiftDCA);
       } // bIsModified
@@ -1326,6 +1325,7 @@ void AddEditPropSheet::OnOk(wxCommandEvent& /* evt */)
       m_item.SetAutoType(tostringx(m_autotype));
       m_item.SetRunCommand(tostringx(m_runcmd));
       m_item.SetDCA(m_DCA);
+      m_item.SetShiftDCA(m_ShiftDCA);
       time(&t);
       m_item.SetCTime(t);
       if (m_keepPWHist)
@@ -1545,7 +1545,7 @@ PWPolicy AddEditPropSheet::GetPWPolicyFromUI()
 {
   Validate(); TransferDataFromWindow();
   wxASSERT_MSG(m_ourPWPRB->GetValue() && !m_defPWPRB->GetValue(), wxT("Trying to get Password policy from UI when db defaults are to be used"));
-  
+
   PWPolicy pwp;
 
   pwp.length = m_pwpLenCtrl->GetValue();
@@ -1578,8 +1578,8 @@ PWPolicy AddEditPropSheet::GetPWPolicyFromUI()
   if (m_pwpHexCtrl->GetValue())
     pwp.flags = PWPolicy::UseHexDigits; //yes, its '=' and not '|='
 
-  if (m_useownsymbols) 
-    pwp.symbols = m_symbols.c_str(); 
+  if (m_useownsymbols)
+    pwp.symbols = m_symbols.c_str();
 
   return pwp;
 }
@@ -1589,7 +1589,7 @@ PWPolicy AddEditPropSheet::GetSelectedPWPolicy()
   PWPolicy pwp;
   if (m_defPWPRB->GetValue()) {
     const wxString polName = m_cbxPolicyNames->GetValue();
-    m_core.GetPolicyFromName(polName.c_str(), pwp);
+    m_core.GetPolicyFromName(tostringx(polName), pwp);
   } else
     pwp = GetPWPolicyFromUI();
   return pwp;
@@ -1606,7 +1606,7 @@ void AddEditPropSheet::OnUpdateResetPWPolicyButton(wxUpdateUIEvent& evt)
  * "at least" lengths.  This is not comprehensive & foolproof
  * since there are far too many ways to make the password length
  * smaller than the sum of "at least" lengths, to even think of.
- * 
+ *
  * In OnOk(), we just ensure the password length is greater than
  * the sum of all enabled "at least" lengths.  We have to do this in the
  * UI, or else password generation crashes
@@ -1653,15 +1653,16 @@ void AddEditPropSheet::OnEZreadCBClick(wxCommandEvent& evt)
       m_pwpEasyCtrl->SetValue(false);
       wxMessageBox(_("Sorry, \"easy-to-read\" and \"pronouncable\" cannot be both selected"),
                    _("Error"), wxOK|wxICON_ERROR, this);
-      return;      
+      return;
     }
+
     CPasswordCharPool::GetEasyVisionSymbols(st_symbols);
   } else { // not checked - restore default symbols to appropriate value
     if (m_pwpPronounceCtrl->GetValue())
       CPasswordCharPool::GetPronounceableSymbols(st_symbols);
     else
       CPasswordCharPool::GetDefaultSymbols(st_symbols);
-  }    
+  }
   FindWindow(IDC_STATIC_DEFAULT_SYMBOLS)->SetLabel(st_symbols.c_str());
 }
 
@@ -1679,7 +1680,7 @@ void AddEditPropSheet::OnPronouceableCBClick( wxCommandEvent& evt)
       m_pwpPronounceCtrl->SetValue(false);
       wxMessageBox(_("Sorry, \"pronouncable\" and \"easy-to-read\" cannot be both selected"),
                    _("Error"), wxOK|wxICON_ERROR, this);
-      return;      
+      return;
     }
     CPasswordCharPool::GetPronounceableSymbols(st_symbols);
   } else { // not checked - restore default symbols to appropriate value
@@ -1687,7 +1688,7 @@ void AddEditPropSheet::OnPronouceableCBClick( wxCommandEvent& evt)
       CPasswordCharPool::GetEasyVisionSymbols(st_symbols);
     else
       CPasswordCharPool::GetDefaultSymbols(st_symbols);
-  }    
+  }
   FindWindow(IDC_STATIC_DEFAULT_SYMBOLS)->SetLabel(st_symbols.c_str());
 }
 
@@ -1734,11 +1735,11 @@ void AddEditPropSheet::OnSendButtonClick( wxCommandEvent& event )
    * sAddress[sHeaders]
    *
    * sAddress
-   *  One or more valid email addresses separated by a semicolon. 
+   *  One or more valid email addresses separated by a semicolon.
    *  You must use Internet-safe characters. Use %20 for the space character.
    *
    * sHeaders
-   *  Optional. One or more name-value pairs. The first pair should be 
+   *  Optional. One or more name-value pairs. The first pair should be
    *  prefixed by a "?" and any additional pairs should be prefixed by a "&".
    *
    *  The name can be one of the following strings:
@@ -1747,7 +1748,7 @@ void AddEditPropSheet::OnSendButtonClick( wxCommandEvent& event )
    *    body
    *       Text to appear in the body of the message.
    *    CC
-   *       Addresses to be included in the "cc" (carbon copy) section of the 
+   *       Addresses to be included in the "cc" (carbon copy) section of the
    *       message.
    *    BCC
    *       Addresses to be included in the "bcc" (blind carbon copy) section
@@ -1757,8 +1758,8 @@ void AddEditPropSheet::OnSendButtonClick( wxCommandEvent& event )
    *   user@example.com?subject=Message Title&body=Message Content"
    */
   if (Validate() && TransferDataFromWindow() && !m_email.IsEmpty()) {
-    StringX mail_cmd=_("mailto:");
-    mail_cmd += m_email.c_str();
+    StringX mail_cmd= tostringx(_("mailto:"));
+    mail_cmd += tostringx(m_email);
     PWSRun runner;
     runner.issuecmd(mail_cmd, wxT(""), false);
   }
@@ -1776,8 +1777,8 @@ void AddEditPropSheet::OnPolicylistSelected( wxCommandEvent& event )
   if (polName == _("Default Policy")) {
     policy = PWSprefs::GetInstance()->GetDefaultPolicy();
   } else {
-    if (!m_core.GetPolicyFromName(polName.c_str(), policy)) {
-      pws_os::Trace(_("Couldn't find policy %s\n"), polName.c_str());
+    if (!m_core.GetPolicyFromName(tostringx(polName), policy)) {
+      pws_os::Trace(_("Couldn't find policy %s\n"), ToStr(polName));
       return;
     }
   }
