@@ -21,20 +21,24 @@
 #endif
 
 ////@begin includes
+#include "SafeCombinationCtrl.h"
 ////@end includes
 
 #include "safecombinationprompt.h"
 #include "os/file.h"
 #include "./wxutils.h"
-#include "./SafeCombinationCtrl.h"
 
 #ifdef __WXMSW__
 #include <wx/msw/msvcrt.h>
 #endif
 
+#ifndef NO_YUBI
 ////@begin XPM images
-#include "./graphics/cpane.xpm"
+#include "graphics/Yubikey-button.xpm"
 ////@end XPM images
+#endif
+
+#include "./graphics/cpane.xpm"
 
 
 /*!
@@ -50,13 +54,18 @@ IMPLEMENT_CLASS( CSafeCombinationPrompt, wxDialog )
 
 BEGIN_EVENT_TABLE( CSafeCombinationPrompt, wxDialog )
 
+#ifndef NO_YUBI
 ////@begin CSafeCombinationPrompt event table entries
+  EVT_BUTTON( ID_YUBIBTN, CSafeCombinationPrompt::OnYubibtnClick )
+
+////@end CSafeCombinationPrompt event table entries
+EVT_TIMER(POLLING_TIMER_ID, CSafeCombinationPrompt::OnPollingTimer)
+#endif
+
   EVT_BUTTON( wxID_OK, CSafeCombinationPrompt::OnOkClick )
 
   EVT_BUTTON( wxID_CANCEL, CSafeCombinationPrompt::OnCancelClick )
 
-////@end CSafeCombinationPrompt event table entries
-
 END_EVENT_TABLE()
 
 
@@ -93,6 +102,11 @@ bool CSafeCombinationPrompt::Create( wxWindow* parent, wxWindowID id, const wxSt
   }
   Centre();
 ////@end CSafeCombinationPrompt creation
+#ifndef NO_YUBI
+  SetupMixin(FindWindow(ID_YUBIBTN), FindWindow(ID_YUBISTATUS));
+  m_pollingTimer = new wxTimer(this, POLLING_TIMER_ID);
+  m_pollingTimer->Start(250); // check for Yubikey every 250ms.
+#endif
   return true;
 }
 
@@ -105,6 +119,9 @@ CSafeCombinationPrompt::~CSafeCombinationPrompt()
 {
 ////@begin CSafeCombinationPrompt destruction
 ////@end CSafeCombinationPrompt destruction
+#ifndef NO_YUBI
+  delete m_pollingTimer;
+#endif
 }
 
 
@@ -115,6 +132,12 @@ CSafeCombinationPrompt::~CSafeCombinationPrompt()
 void CSafeCombinationPrompt::Init()
 {
 ////@begin CSafeCombinationPrompt member initialisation
+  m_scctrl = NULL;
+#ifndef NO_YUBI
+  m_YubiBtn = NULL;
+  m_yubiStatusCtrl = NULL;
+#endif
+  
 ////@end CSafeCombinationPrompt member initialisation
 }
 
@@ -129,7 +152,7 @@ void CSafeCombinationPrompt::CreateControls()
   CSafeCombinationPrompt* itemDialog1 = this;
 
   wxBoxSizer* itemBoxSizer2 = new wxBoxSizer(wxVERTICAL);
-//  itemDialog1->SetSizer(itemBoxSizer2);
+  itemDialog1->SetSizer(itemBoxSizer2);
 
   wxBoxSizer* itemBoxSizer3 = new wxBoxSizer(wxHORIZONTAL);
   itemBoxSizer2->Add(itemBoxSizer3, 0, wxALIGN_CENTER_HORIZONTAL|wxALL, 5);
@@ -152,17 +175,42 @@ void CSafeCombinationPrompt::CreateControls()
   wxStaticText* itemStaticText9 = new wxStaticText( itemDialog1, wxID_STATIC, _("Safe\ncombination:"), wxDefaultPosition, wxDefaultSize, 0 );
   itemBoxSizer8->Add(itemStaticText9, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
-  CSafeCombinationCtrl* scctrl = new CSafeCombinationCtrl( itemDialog1, ID_PASSWORD, &m_password, wxDefaultPosition, wxSize(itemDialog1->ConvertDialogToPixels(wxSize(150, -1)).x, -1));
-  itemBoxSizer8->Add(scctrl, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+  m_scctrl = new CSafeCombinationCtrl( itemDialog1, ID_PASSWORD, &m_password, wxDefaultPosition, wxSize(itemDialog1->ConvertDialogToPixels(wxSize(150, -1)).x, -1) );
+  itemBoxSizer8->Add(m_scctrl, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
 
-  itemBoxSizer2->Add(CreateStdDialogButtonSizer(wxOK|wxCANCEL|wxHELP), wxSizerFlags().Border().Expand().Proportion(0));
+  wxBoxSizer* itemBoxSizer11 = new wxBoxSizer(wxHORIZONTAL);
+  itemBoxSizer5->Add(itemBoxSizer11, 0, wxGROW|wxALL, 5);
+
+#ifndef NO_YUBI
+  m_YubiBtn = new wxBitmapButton( itemDialog1, ID_YUBIBTN, itemDialog1->GetBitmapResource(wxT("graphics/Yubikey-button.xpm")), wxDefaultPosition, itemDialog1->ConvertDialogToPixels(wxSize(40, 15)), wxBU_AUTODRAW );
+  itemBoxSizer11->Add(m_YubiBtn, 0, wxALIGN_CENTER_VERTICAL|wxLEFT|wxRIGHT|wxBOTTOM|wxSHAPED, 5);
+#endif
+
+  itemBoxSizer11->Add(4, 10, 0, wxALIGN_CENTER_VERTICAL|wxALL, 1);
+
+#ifndef NO_YUBI
+  m_yubiStatusCtrl = new wxStaticText( itemDialog1, ID_YUBISTATUS, _("Please insert your YubiKey"), wxDefaultPosition, wxDefaultSize, 0 );
+  itemBoxSizer11->Add(m_yubiStatusCtrl, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5);
+#endif
+
+  wxStdDialogButtonSizer* itemStdDialogButtonSizer15 = new wxStdDialogButtonSizer;
+
+  itemBoxSizer2->Add(itemStdDialogButtonSizer15, 0, wxGROW|wxALL, 5);
+  wxButton* itemButton16 = new wxButton( itemDialog1, wxID_OK, _("&OK"), wxDefaultPosition, wxDefaultSize, 0 );
+  itemButton16->SetDefault();
+  itemStdDialogButtonSizer15->AddButton(itemButton16);
+
+  wxButton* itemButton17 = new wxButton( itemDialog1, wxID_CANCEL, _("&Cancel"), wxDefaultPosition, wxDefaultSize, 0 );
+  itemStdDialogButtonSizer15->AddButton(itemButton17);
+
+  wxButton* itemButton18 = new wxButton( itemDialog1, wxID_HELP, _("&Help"), wxDefaultPosition, wxDefaultSize, 0 );
+  itemStdDialogButtonSizer15->AddButton(itemButton18);
+
+  itemStdDialogButtonSizer15->Realize();
 
-  SetSizerAndFit(itemBoxSizer2);
-  
   // Set validators
   itemStaticText7->SetValidator( wxGenericValidator(& m_filename) );
 ////@end CSafeCombinationPrompt content construction
-
   wxWindow* passwdCtrl = FindWindow(ID_PASSWORD);
   if (passwdCtrl) {
     passwdCtrl->SetFocus();
@@ -193,6 +241,13 @@ wxBitmap CSafeCombinationPrompt::GetBitmapResource( const wxString& name )
     wxBitmap bitmap(cpane_xpm);
     return bitmap;
   }
+#ifndef NO_YUBI
+  else if (name == _T("graphics/Yubikey-button.xpm"))
+  {
+    wxBitmap bitmap(Yubikey_button_xpm);
+    return bitmap;
+  }
+#endif
   return wxNullBitmap;
 ////@end CSafeCombinationPrompt bitmap retrieval
 }
@@ -211,6 +266,30 @@ wxIcon CSafeCombinationPrompt::GetIconResource( const wxString& name )
 }
 
 
+void CSafeCombinationPrompt::ProcessPhrase()
+{
+  if (m_core.CheckPasskey(tostringx(m_filename),
+                          m_password) != PWScore::SUCCESS) {
+    wxString errmess;
+    if (m_tries >= 2) {
+      errmess = _("Three strikes - yer out!");
+    } else {
+      m_tries++;
+      errmess = _("Incorrect passkey, not a PasswordSafe database, or a corrupt database. (Backup database has same name as original, ending with '~')");
+    }
+    wxMessageDialog err(this, errmess,
+                        _("Error"), wxOK | wxICON_EXCLAMATION);
+    err.ShowModal();
+    wxTextCtrl *txt = dynamic_cast<wxTextCtrl *>(FindWindow(ID_PASSWORD));
+    txt->SetSelection(-1,-1);
+    txt->SetFocus();
+    return;
+  }
+  // m_core.SetReadOnly(m_readOnly);
+  m_core.SetCurFile(tostringx(m_filename));
+  EndModal(wxID_OK);
+}
+
 /*!
  * wxEVT_COMMAND_BUTTON_CLICKED event handler for wxID_OK
  */
@@ -230,26 +309,7 @@ void CSafeCombinationPrompt::OnOkClick( wxCommandEvent& /* evt */ )
       err.ShowModal();
       return;
     }
-    if (m_core.CheckPasskey(tostringx(m_filename),
-                            m_password) != PWScore::SUCCESS) {
-      wxString errmess;
-      if (m_tries >= 2) {
-        errmess = _("Three strikes - yer out!");
-      } else {
-        m_tries++;
-        errmess = _("Incorrect passkey, not a PasswordSafe database, or a corrupt database. (Backup database has same name as original, ending with '~')");
-      }
-      wxMessageDialog err(this, errmess,
-                          _("Error"), wxOK | wxICON_EXCLAMATION);
-      err.ShowModal();
-      wxTextCtrl *txt = dynamic_cast<wxTextCtrl *>(FindWindow(ID_PASSWORD));
-      txt->SetSelection(-1,-1);
-      txt->SetFocus();
-      return;
-    }
-    // m_core.SetReadOnly(m_readOnly);
-    m_core.SetCurFile(tostringx(m_filename));
-    EndModal(wxID_OK);
+    ProcessPhrase();
   }
 }
 
@@ -266,3 +326,36 @@ void CSafeCombinationPrompt::OnCancelClick( wxCommandEvent& /* evt */ )
 ////@end wxEVT_COMMAND_BUTTON_CLICKED event handler for wxID_CANCEL in CSafeCombinationPrompt. 
 }
 
+
+#ifndef NO_YUBI
+/*!
+ * wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_YUBIBTN
+ */
+
+void CSafeCombinationPrompt::OnYubibtnClick( wxCommandEvent& /* event */ )
+{
+  m_scctrl->AllowEmptyCombinationOnce();  // Allow blank password when Yubi's used
+  if (Validate() && TransferDataFromWindow()) {
+    if (!pws_os::FileExists(tostdstring(m_filename))) {
+      wxMessageDialog err(this, _("File or path not found."),
+                          _("Error"), wxOK | wxICON_EXCLAMATION);
+      err.ShowModal();
+      return;
+    }
+
+    StringX response;
+    if (PerformChallengeResponse(m_password, response)) {
+      m_password = response;
+      ProcessPhrase();
+      UpdateStatus();
+    }
+  }
+}
+
+void CSafeCombinationPrompt::OnPollingTimer(wxTimerEvent &evt)
+{
+  if (evt.GetId() == POLLING_TIMER_ID) {
+    HandlePollingTimer(); // in CYubiMixin
+  }
+}
+#endif
